@@ -869,6 +869,7 @@ void Data_Provider::parseData()
 			{
 				if ( urlc_follow_xml != "" )
 				{
+					qDebug() << "Downloading urlc follow: " << KUrl( urlc_new );
 					url_follow_job_success_list[0] = false;
 					data_download_data_list[0] = QByteArray();
 					KIO::Job *jobc = KIO::get( KUrl( urlc_new ), KIO::Reload, KIO::HideProgressInfo );
@@ -880,6 +881,7 @@ void Data_Provider::parseData()
 
 				if ( url1_follow_xml != "" )
 				{
+					qDebug() << "Downloading url1 follow: " << KUrl( url1_new );
 					url_follow_job_success_list[1] = false;
 					data_download_data_list[1] = QByteArray();
 					KIO::Job *job1 = KIO::get( KUrl( url1_new ), KIO::Reload, KIO::HideProgressInfo );
@@ -891,6 +893,7 @@ void Data_Provider::parseData()
 
 				if ( url2_follow_xml != "" )
 				{
+					qDebug() << "Downloading url2 follow: " << KUrl( url2_new );
 					url_follow_job_success_list[2] = false;
 					data_download_data_list[2] = QByteArray();
 					KIO::Job *job2 = KIO::get( KUrl( url2_new ), KIO::Reload, KIO::HideProgressInfo );
@@ -902,6 +905,7 @@ void Data_Provider::parseData()
 
 				if ( url3_follow_xml != "" )
 				{
+					qDebug() << "Downloading url3 follow: " << KUrl( url3_new );
 					url_follow_job_success_list[3] = false;
 					data_download_data_list[3] = QByteArray();
 					KIO::Job *job3 = KIO::get( KUrl( url3_new ), KIO::Reload, KIO::HideProgressInfo );
@@ -913,6 +917,7 @@ void Data_Provider::parseData()
 
 				if ( url4_follow_xml != "" )
 				{
+					qDebug() << "Downloading url4 follow: " << KUrl( url4_new );
 					url_follow_job_success_list[4] = false;
 					data_download_data_list[4] = QByteArray();
 					KIO::Job *job4 = KIO::get( KUrl( url4_new ), KIO::Reload, KIO::HideProgressInfo );
@@ -924,6 +929,7 @@ void Data_Provider::parseData()
 
 				if ( url5_follow_xml != "" )
 				{
+					qDebug() << "Downloading url5 follow: " << KUrl( url5_new );
 					url_follow_job_success_list[5] = false;
 					data_download_data_list[5] = QByteArray();
 					KIO::Job *job5 = KIO::get( KUrl( url5_new ), KIO::Reload, KIO::HideProgressInfo );
@@ -935,6 +941,7 @@ void Data_Provider::parseData()
 
 				if ( url6_follow_xml != "" )
 				{
+					qDebug() << "Downloading url6 follow: " << KUrl( url6_new );
 					url_follow_job_success_list[6] = false;
 					data_download_data_list[6] = QByteArray();
 					KIO::Job *job6 = KIO::get( KUrl( url6_new ), KIO::Reload, KIO::HideProgressInfo );
@@ -946,6 +953,7 @@ void Data_Provider::parseData()
 
 				if ( url7_follow_xml != "" )
 				{
+					qDebug() << "Downloading url7 follow: " << KUrl( url7_new );
 					url_follow_job_success_list[7] = false;
 					data_download_data_list[7] = QByteArray();
 					KIO::Job *job7 = KIO::get( KUrl( url7_new ), KIO::Reload, KIO::HideProgressInfo );
