@@ -453,7 +453,7 @@ void PaintHelper::drawWind( QPainter *p, const QRect &rectangle, const QString &
 	if ( invertWindRose ) add_rotation = 180.0;
 
 	QTransform transform;
-	int arrow_var_unknown = 0; // 0=arrow, 1=var, 2=unknown
+	int arrow_var_unknown = 0; // 0=arrow, 1=var, 2=unknown, 3=calm
 	if ( code == "N" )				transform.rotate( -270.0 + add_rotation, Qt::ZAxis );
 	else if ( code == "NNE" ) transform.rotate( -247.5 + add_rotation, Qt::ZAxis );
 	else if ( code == "NE" )	transform.rotate( -225.0 + add_rotation, Qt::ZAxis );
@@ -471,12 +471,14 @@ void PaintHelper::drawWind( QPainter *p, const QRect &rectangle, const QString &
 	else if ( code == "NW" )	transform.rotate( -315.0 + add_rotation, Qt::ZAxis );
 	else if ( code == "NNW" ) transform.rotate( -292.5 + add_rotation, Qt::ZAxis );
 	else if ( code == "Var" ) arrow_var_unknown = 1;
-	else											arrow_var_unknown = 2;
+	else if ( code == "Calm" ) arrow_var_unknown = 3;
+	else arrow_var_unknown = 2;
 
 	QString svg_file = QString();
 
 	if ( arrow_var_unknown == 0 ) svg_file = "widgets/wind_arrow";
 	else if ( arrow_var_unknown == 1 ) svg_file = "widgets/wind_var";
+	else if ( arrow_var_unknown == 3 ) svg_file = "widgets/wind_calm";
 	else svg_file = "widgets/wind_unknown";
 
 	Plasma::Svg* svg;
